==> viettqt-typscript-redis-package-1.0.0.tgz: package/lib/index.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
// @ts-ignore
import { createClient } from '@redis/client';
class RedisInteractive {
    /**
     * Connect redis
     */
    static connectRedis() {
        return __awaiter(this, void 0, void 0, function* () {
            const client = createClient();
            client.on('error', (err) => console.log('Redis Client Error', err));
            yield client.connect();
            return client;
        });
    }
    /**
     * check data in redis cache
     * @param dataRedis
     */
    static getCacheRedis(dataRedis) {
        return __awaiter(this, void 0, void 0, function* () {
            const redis = yield this.connectRedis();
            const checkFiled = yield redis.hExists(dataRedis.key, dataRedis.field);
            if (!checkFiled) {
                return false;
            }
            const result = yield redis.hGet(dataRedis.key, dataRedis.field);
            yield redis.disconnect();
            return JSON.parse(result);
        });
    }
    /**
     * Save data to redis
     * @param dataRedis
     * @param data
     */
    static saveDataRedis(dataRedis, data) {
        return __awaiter(this, void 0, void 0, function* () {
            const redis = yield this.connectRedis();
            yield redis.hSet(dataRedis.key, dataRedis.field, JSON.stringify(data));
            yield redis.disconnect();
        });
    }
    /**
     * Delete field redis
     * @param key
     */
    static delDataRedis(key) {
        return __awaiter(this, void 0, void 0, function* () {
            const redis = yield this.connectRedis();
            yield redis.del(key);
            yield redis.disconnect();
        });
    }
}
function test() {
    return __awaiter(this, void 0, void 0, function* () {
        yield RedisInteractive.saveDataRedis({ key: 'viet', field: 'aaaa' }, [{ name: 'vvvvv' }]);
    });
}
test();

==> viettqt-typscript-redis-package-1.0.1.tgz: package/lib/index.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
// @ts-ignore
import { createClient } from '@redis/client';
export class RedisInteractive {
    /**
     * Connect redis
     */
    static connectRedis() {
        return __awaiter(this, void 0, void 0, function* () {
            const client = createClient();
            client.on('error', (err) => console.log('Redis Client Error', err));
            yield client.connect();
            return client;
        });
    }
    /**
     * check data in redis cache
     * @param dataRedis
     */
    static getCacheRedis(dataRedis) {
        return __awaiter(this, void 0, void 0, function* () {
            const redis = yield this.connectRedis();
            const checkFiled = yield redis.hExists(dataRedis.key, dataRedis.field);
            if (!checkFiled) {
                return false;
            }
            const result = yield redis.hGet(dataRedis.key, dataRedis.field);
            yield redis.disconnect();
            return JSON.parse(result);
        });
    }
    /**
     * Save data to redis
     * @param dataRedis
     * @param data
     */
    static saveDataRedis(dataRedis, data) {
        return __awaiter(this, void 0, void 0, function* () {
            const redis = yield this.connectRedis();
            yield redis.hSet(dataRedis.key, dataRedis.field, JSON.stringify(data));
            yield redis.disconnect();
        });
    }
    /**
     * Delete field redis
     * @param key
     */
    static delDataRedis(key) {
        return __awaiter(this, void 0, void 0, function* () {
            const redis = yield this.connectRedis();
            yield redis.del(key);
            yield redis.disconnect();
        });
    }
}
